function [Positions] = GetPlaceOnSOM(Samples, SOMWeights, GridSize, NormType)
// bildet Beispielvektoren auf Position auf einer selbstorganisierenden Merkmalskarte ab.
//
// Calling Sequence
//   [Positions] = GetPlaceOnSOM(Samples, SOMWeights, GridSize, NormType)
//
// Parameters
// Samples: Matrix, die Beispielvektoren als Zeilen enthält
// InitialWeights: Matrix, die Gewichtsvektoren als Zeilen enthält
// GridSize: Vektor oder Skalar, gibt die Anzahl der Neuronen pro Dimension an. Alle Elemente müssen größer als eins sein.
// NormType: Norm der Vektoren, ist Skalar größer als null, kann %inf sein
// Positions: Matrix, die Positionen auf der selbstorganisierenden Merkmalskarte als Zeilen enthält 
//
// Description
// Diese Funktion sucht zu jeder Zeile von Samples den nächten Nachbarn unter 
// den Zeilen von SOMWeights und bildet diesen auf den entsprechenden Platz auf
// der selbstorganisierenden Merkmalskarte ab.
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  GridSize = [5 3];
//  SOMWeights = InitSOM(Samples, GridSize, 'equidistant');
//  Positions = GetPlaceOnSOM(Samples(1 : 5, :), SOMWeights, GridSize, 2)
//
// See also
//  SelectRandomly
//  InitSOM
//  TrainSOM
//
// Authors
//  Dr. Eng. (J) Harald Galda ; 
//
// Bibliography
//   T. Kohonen, 'Self-organizing maps', Springer Verlag, Berlin, 2001

// start of coding after on empty line to mark the end of the head_comments section
// This file is for XML file generation only.
endfunction
