function [Positions] = GetPlaceOnSOM(Samples, SOMWeights, GridSize, NormType)
// maps sample vectors to places on self organizing map.
//
// Calling Sequence
//   [Positions] = GetPlaceOnSOM(Samples, SOMWeights, GridSize, NormType)
//
// Parameters
// Samples: matrix that includes sample vectors as rows
// SOMWeights: matrix that includes SOM weight vectors as rows
// GridSize: vector or scalar, specifies the number of neurons per SOM dimension. All elements must be greater than one.
// NormType: norm of vectors, must be a scalar greater than zeros, can be %inf
// Positions: matrix that includes position vectors as rows 
//
// Description
// For each row of samples the nearest neighbor among the row vectors of
// SOMWeights is searched and mapped to the corresponding position on the SOM.
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  GridSize = [5 3];
//  SOMWeights = InitSOM(Samples, GridSize, 'equidistant');
//  Positions = GetPlaceOnSOM(Samples(1 : 5, :), SOMWeights, GridSize, 2)
//
// See also
//  SelectRandomly
//  InitSOM
//  TrainSOM
//
// Authors
//  Dr. Eng. (J) Harald Galda ; 
//
// Bibliography
//   T. Kohonen, 'Self-organizing maps', Springer Verlag, Berlin, 2001

// start of coding after on empty line to mark the end of the head_comments section
// This file is for XML file generation only.
endfunction
