﻿function [Positions] = GetPlaceOnSOM(Samples, SOMWeights, GridSize, NormType)
// はサンプルを自己組織化マップにおける位置に写像する
//
// Calling Sequence
//   [Positions] = GetPlaceOnSOM(Samples, SOMWeights, GridSize, NormType)
//
// Parameters
// Samples:サンプルを含む行列で、サンプルは行である
// SOMWeights:ウェイトを含む行列で、ウェイトは行である
// GridSize:各次元におけるニューロンの数を表すベクトル又はスカラーである。構成要素が1つを超える必要はある.
// NormType:ベクトルにおけるノルムで、ゼロを超える数で、無限（%inf）である可能性がある
// Positions: matrix that includes position vectors as rows 
//
// Description
// 本関数はSamplesの行を最も近いSOMWeightsの行に写像して、発見された行のインデックスを自己組織化マップにおける位置に写像する。
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  GridSize = [5 3];
//  SOMWeights = InitSOM(Samples, GridSize, 'equidistant');
//  Positions = GetPlaceOnSOM(Samples(1 : 5, :), SOMWeights, GridSize, 2)
//
// See also
//  SelectRandomly
//  InitSOM
//  TrainSOM
//
// Authors
//  画留田ハラルド ; 
//
// Bibliography
//   T. Kohonen, 'Self-organizing maps', Springer Verlag, Berlin, 2001

// start of coding after on empty line to mark the end of the head_comments section
// This file is for XML file generation only.
endfunction
